@@ -5,9 +5,12 @@ This is the area where common functionality for scanning folders is collected.
 import json
 import logging
 import os
+import pathlib
 import tempfile
 import shutil
+import copy
 import zipfile
+import subprocess
 import fnmatch
 from typing import Optional, Tuple, Dict, List, Union
 import yaml
@@ -25,6 +28,7 @@ from coguard_cli.auth.token import Token
 from coguard_cli import docker_dao
 from coguard_cli import image_check
 from coguard_cli.additional_scan_results import perform_external_scans_and_return_folders
+from coguard_cli.discovery.config_file_finders import create_temp_location_and_manifest_entry
 
 def filter_config_file_list(
         config_file_list: List[Tuple[Dict, str]],
@@ -345,6 +349,38 @@ def _find_and_merge_included_docker_images(
     if to_add:
         additional_failed_rules.append("cluster_docker_images_with_failed_checks_included")
 
+def _find_and_extract_cdk_json(folder_name: str):
+    """
+    Helper function to see if there is a CDK.json and performing the
+    extraction.
+    """
+    cdk_config_path = pathlib.Path(folder_name).joinpath('cdk.json')
+    if not cdk_config_path.exists():
+        return
+    try:
+        logging.info("Running `cdk synth` in %s", folder_name)
+
+        # Run cdk synth, suppressing interactive prompts
+        result = subprocess.run(
+            ["cdk", "synth"],
+            cwd=str(folder_name),
+            stdout=subprocess.PIPE,
+            stderr=subprocess.PIPE,
+            check=False
+        )
+
+        if result.returncode == 0:
+            logging.info("cdk synth succeeded")
+        else:
+            logging.warning(
+                "cdk synth failed (exit %d). stderr: %s",
+                result.returncode,
+                result.stderr.strip(),
+            )
+    #pylint: disable=broad-exception-caught
+    except Exception as ex:
+        logging.error("Unexpected errorrunning cdk synth: %s", ex)
+
 def perform_folder_scan(
         folder_name: Optional[str],
         deal_type: DealEnum,
@@ -356,7 +392,8 @@ def perform_folder_scan(
         fail_level: int,
         ruleset: str,
         dry_run: bool = False,
-        external_results_to_send = None):
+        external_results_to_send = None,
+        collect_additional_failed_rules = True):
     """
     Helper function to run a scan on a folder. If the folder_name parameter is None,
     the current working directory is being used.
@@ -364,6 +401,7 @@ def perform_folder_scan(
     folder_name = folder_name or os.path.abspath(".")
     coguard_ignore_list = coguard_cli.util.retrieve_coguard_ignore_values(folder_name)
     printed_folder_name = os.path.basename(os.path.dirname(folder_name + os.sep))
+    _find_and_extract_cdk_json(folder_name)
     print(f"{COLOR_CYAN}SCANNING FOLDER {COLOR_TERMINATION}{printed_folder_name}")
     collected_config_file_tuple = find_configuration_files_and_collect(
         folder_name,
@@ -374,7 +412,8 @@ def perform_folder_scan(
         print(f"{COLOR_YELLOW}FOLDER {printed_folder_name} - NO CONFIGURATION FILES FOUND.")
         return
     additional_failed_rules = []
-    is_ci_cd_there(folder_name, additional_failed_rules)
+    if collect_additional_failed_rules:
+        is_ci_cd_there(folder_name, additional_failed_rules)
     _find_and_merge_included_docker_images(
         collected_config_file_tuple,
         auth_config,
